@@ -10,7 +10,10 @@ from ._characteristic_function import ecf
 from ._kernel_transform import kernel_transform
 from ._teager import teager
 from ._kernel_matrix import kernel_matrix
-from ._lags_matrix import lags_matrix, covariance_matrix
+from ._lags_matrix import lags_matrix, covariance_matrix, conv_matrix
 from ._diagnalization import diaganal_average
 from ._tls_turnication import tls_turnication
-from ._elementary import diff,arg,afft
\ No newline at end of file
+from ._elementary import diff,arg,afft
+from ._hilbert import hilbert, hilbert_autocorrelation
+from ._hht import hht
+from ._smoothing import moving_average
\ No newline at end of file
